@@ -24,7 +24,7 @@ use BeamerReveal::FrameConverter;
 
 sub dieExit;
 
-my $version = 0.9;
+my $version = 0.95;
 my $author  = 'Walter Daems <walter.daems@uantwerpen.be>';
 
 ######################################
@@ -54,23 +54,6 @@ pod2usage( -message => "Incorrect number of arguments",
 					  or
 					  defined( $argument ) );
 
-###################
-# Read config file
-#################
-# use 1. specific location if BEAMERREVEAL_CONFIG is set,
-#     2. else, home configuration folder,
-#     3. or else, distribution folder
-my $home = $^O eq 'MSWin32' ? $ENV{'userprofile'} : $ENV{'HOME'};
-my $configDir = $ENV{'BEAMERREVEAL_CONFIG'}
-  // "$home/.config/BeamerReveal";
-my $configFileName = "$configDir/config.ini";
-$configFileName = File::ShareDir::dist_dir( 'BeamerReveal' ) . '/config.ini'
-  if ( ! -r $configFileName );
-dieExit( 13, "Error: cannot find config file $configFileName" )
-  unless( -r $configFileName );
-my $config = Config::Tiny->read( $configFileName )
-  or dieExit( 14, $Config::Tiny::errstr . "\nin file '$configFileName'\n" );
-
 ########################
 # generate opening line
 ######################
@@ -78,18 +61,15 @@ my $openingline = "beamer-reveal.pl - v$version - $author";
 say STDERR $openingline . "\n" .
   ("=" x length( $openingline ) );
 
-say STDERR "- Reading configuration file from $configFileName";
-
-if( $opt_showconfig ) {
-  say STDERR Data::Dumper->Dump( [ $config ], [ qw(Configuration) ] );
-  exit(0);
-}
-
 ###################
 # do the hard work
 #################
 
+# fetch the jobname and get rid of these nasty windows backslashes...
 my ( $jobname ) = @ARGV;
+$jobname =~ s/\\/\//g;
+
+# fetch the reveal file
 my $rvlFileName = $jobname . ".rvl";
 say STDERR "- Reading driver file $rvlFileName";
 my $rvlFile = IO::File->new();
@@ -140,7 +120,6 @@ eval {
 my $mediaManager =
   BeamerReveal::MediaManager->new( $jobname,
 				   "${jobname}_files",
-				   $config,
 				   $presentation->{parameters} );
 
 # storing the reveal framework
@@ -215,7 +194,7 @@ beamer-reveal.pl - converts the .rvl file and the corresponding pdf file to a fu
 
 =head1 VERSION
 
-version 20251226.1345
+version 20251226.2007
 
 =head1 SYNOPSIS
 
