@@ -20,9 +20,9 @@ use Data::UUID;
 
 use IO::File;
 
-use IPC::System::Simple qw(system);
-
-use Parallel::ForkManager;
+use MCE;
+use MCE::Loop;
+use MCE::Util;
 
 use BeamerReveal::TemplateStore;
 use BeamerReveal::IPC::Run;
@@ -31,10 +31,9 @@ sub min { $_[$_[0] > $_[1] ] }
 sub nofdigits { length( "$_[0]" ) }
 
 
-
 sub new {
   my $class = shift;
-  my ( $jobname, $base, $config, $presentationprms ) = @_;
+  my ( $jobname, $base, $presentationprms ) = @_;
 
   my $self = {
 	      jobname => $jobname,
@@ -57,7 +56,6 @@ sub new {
   # $self->{iframes}    = File::Spec->catfile( $self->{base}, 'media', 'Iframes' );	
   # $self->{slides}     = File::Spec->catfile( $self->{base}, 'media', 'Slides' );
   # $self->{reveal}     = File::Spec->catfile( $self->{base}, 'libs' );
-  $self->{config} = $config;
   $self->{presentationparameters} = $presentationprms;
   
   # create animations, but don't remove them
@@ -157,7 +155,7 @@ sub animationToStore {
     my $fileContent = BeamerReveal::TemplateStore::stampTemplate( $tTemplate, $tStamps );
 
     my $nofFrames = floor( $animation->{framerate} * $animation->{duration} );
-    my $nofCores  = $self->{config}->{hardware}->{numberofcores};
+    my $nofCores  = ceil( MCE::Util::get_ncpu() / 2 );
     my $sliceSize = ceil( $nofFrames / $nofCores );
 
     say STDERR "      - Preparing media generation of $nofFrames frames in $nofCores threads at $sliceSize frames per thread";
@@ -168,7 +166,9 @@ sub animationToStore {
     for( my $core = 0; $core < $nofCores; ++$core ) {
       # make plan for core
       my $plan = { nstart => $frameCounter,
-		   nstop  => min( $frameCounter + $sliceSize, $nofFrames )};
+		   nstop  => min( $frameCounter + $sliceSize, $nofFrames ),
+		   nr     => $core
+		 };
       $plan->{slicestart} = 1;
       $plan->{slicestop}  = $plan->{nstop} - $plan->{nstart};
       $plan->{nstop}      -= 1;
@@ -180,24 +180,14 @@ sub animationToStore {
       $frameCounter += $sliceSize;
     }
 
-    my $manager = Parallel::ForkManager->new( $nofCores );
-    my $nofFailedChildren = 0;
-    $manager->run_on_finish
-      (
-       sub {
-	 my ( $pid, $exit_code, $ident, $exit_signal, $core_dump ) = @_;
-	 if ( $exit_code != 0 || $exit_signal ) {
-	   ++$nofFailedChildren;
-	 }
-       }
-      );
-    
     my $cmd;
-    $planning->[-1]->{slicestop} = 9;
-    for( my $core = 0; $core < @$planning; ++$core ) {
-      my $coreId = sprintf( '%0' . nofdigits( $nofCores ) . 'd', $core );
+    MCE::Loop::init { max_workers => $nofCores, chunk_size  => 1 };
+    
+    mce_loop {
+      my ( $mce, $chunk_ref, $chunk_id ) = @_;
+      my $plan = $chunk_ref->[0];
+      my $coreId = sprintf( '%0' . nofdigits( $nofCores ) . 'd', $plan->{nr} );
       # generate TeX -file
-      my $plan = $planning->[$core];
       my $perCoreContent = BeamerReveal::TemplateStore::stampTemplate
 	( $fileContent,
 	  {
@@ -206,8 +196,7 @@ sub animationToStore {
 	   NSTART      => $plan->{nstart},
 	  }
 	);
-      
-      #my $texFileName = File::Spec->catfile( $animdir, "animation-$coreId.tex" );
+
       my $texFileName = "$animdir/animation-$coreId.tex";
       my $texFile = IO::File->new();
       $texFile->open( ">$texFileName" )
@@ -215,13 +204,11 @@ sub animationToStore {
       print $texFile $perCoreContent;
       $texFile->close();
 
-      $manager->start() and next;
-      
       # run TeX
       $cmd = [ $self->{compiler},
 	       "--output-directory=$animdir", "$texFileName" ];
       BeamerReveal::IPC::Run::run( $cmd, $coreId, 8 );
-      
+
       # run pdfcrop
       $cmd = [ $self->{pdfcrop}, '--margins', '-2', "animation-$coreId.pdf" ];
       BeamerReveal::IPC::Run::run( $cmd, $coreId, 8, $animdir );
@@ -235,7 +222,7 @@ sub animationToStore {
 	       '-scale-to-y', "$yrange",
 	       "animation-$coreId-crop.pdf", "./frame-$coreId", '-jpeg' ];
       BeamerReveal::IPC::Run::run( $cmd, $coreId, 8, $animdir );
-      
+
       # correct for too short slicesize in filenames coming from pdftoppm
       my $currentDigitCnt = nofdigits( $plan->{slicestop} );
       my $desiredDigitCnt = nofdigits( $sliceSize );
@@ -248,19 +235,10 @@ sub animationToStore {
 	  File::Copy::move( $src, $dst );
 	}
       }
-      $manager->finish();
-    }
-    
-    $manager->wait_all_children();
 
-    if ( $nofFailedChildren ) {
-      die( "Error: animation generation failed; check the log files in $animdir\n" );
-    }
-    else {
-      say STDERR "        - returning to single-threaded operation";
-    }
+    } @$planning;
 
-    
+    say STDERR "        - returning to single-threaded operation";
     
     # rename all files in order
     my $framecounter = 0;
@@ -337,7 +315,7 @@ sub _toStore {
   do {
     my $uuid = $id->create();
     #$fullpathid = File::Spec->catfile( $self->{base}, 'media', $type, $id->to_string( $uuid ) . $ext );
-    $fullpathid = "$self->{base}/media/$type/@{[$id->to_string( $uuid )]}.$ext";
+    $fullpathid = "$self->{base}/media/$type/@{[$id->to_string( $uuid )]}$ext";
   } until( ! -e $fullpathid );
   
   # copy file
@@ -361,7 +339,7 @@ BeamerReveal::MediaManager - MediaManager
 
 =head1 VERSION
 
-version 20251226.1345
+version 20251226.2007
 
 =head1 SYNOPSIS
 
@@ -379,7 +357,7 @@ we reuse the generated video file. If the source data has changed, we regenerate
 
 =head2 new()
 
-  $mm = BeamerReveal::MediaManager->new( $jobname, $base, $config, $presoparams )
+  $mm = BeamerReveal::MediaManager->new( $jobname, $base, $presoparams )
 
 The constructor sets up the manager.
 
@@ -400,11 +378,6 @@ we can read the preamble for reuse in the TikZ animations.
 directory in shiche the media will reside. Typically, this is the base name of the final HTML
 file, followed by the suffix '_files'.
 
-=item . C<$config>
-
-configuration object that can be queried for settings. At this moment this is not very heavily
-used.
-
 =item . C<$presoparams>
 
 parameters of the presentation. This is required to know the compiler and the resolution of the
